==> part_library_gen-0.1.18a0-py3-none-any.whl: part_library_gen/generators/footprint_generator/tssop.py <==
from decimal import Decimal
from .footprint import Footprint
from ..components.pad import Pad
from ..components.lines import Lines
from ..components.circle import Circle


class Parameters:
    def __init__(self, pin_count: int, pin_pitch, pad_width, pad_height, pad_row_spacing):
        self.pin_count = pin_count
        self.pin_pitch = pin_pitch
        self.pad_width = pad_width
        self.pad_height = pad_height
        self.pad_row_spacing = pad_row_spacing


def generate(parameters, name):
    row_spacing = Decimal(parameters['E']) + 2 * Decimal(parameters['b']) - Decimal(parameters['L'])
    overlay_d = Decimal(parameters['D'])
    overlay_e = Decimal(parameters['E']) - Decimal(parameters['L']) - Decimal('0.5')
    parameters = Parameters(20,
                            pin_pitch=Decimal(parameters['e']),
                            pad_width=Decimal(parameters['L']),
                            pad_height=Decimal(parameters['b']) + Decimal('0.06'),
                            pad_row_spacing=Decimal(parameters['L']) + 2*Decimal(parameters['b'])-Decimal(parameters['L']))

    pin_count_per_side = int(parameters.pin_count / 2)
    first_pad_y = pin_count_per_side * parameters.pin_pitch / 2
    left_pads = add_vertical_pads(first=1,
                                  last=10,
                                  pitch=parameters.pin_pitch,
                                  width=parameters.pad_width,
                                  height=parameters.pad_height,
                                  x=row_spacing / -2,
                                  y_offset=first_pad_y)
    right_pads = add_vertical_pads(first=20,
                                   last=11,
                                   pitch=parameters.pin_pitch,
                                   width=parameters.pad_width,
                                   height=parameters.pad_height,
                                   x=row_spacing / 2,
                                   y_offset=first_pad_y)

    footprint = Footprint(name)
    footprint.add_pad(left_pads)
    footprint.add_pad(right_pads)

    # add overlay layer
    overlay_rectangle = Lines(overlay_e / -2, overlay_d / 2)
    overlay_rectangle.add_point(overlay_e / -2, overlay_d / -2)
    overlay_rectangle.add_point(overlay_e / 2, overlay_d / -2)
    overlay_rectangle.add_point(overlay_e / 2, overlay_d / 2)
    footprint.add_overlay(overlay_rectangle)
    radius = Decimal('0.5')
    spacing = Decimal('0.5')
    overlay_one_position_mark = Circle(overlay_e / -2 + radius + spacing, overlay_d / 2 - radius - spacing, radius)
    footprint.add_overlay(overlay_one_position_mark)

    footprint.width = row_spacing + 3
    footprint.height = overlay_d + 2
    return footprint


def add_vertical_pads(first, last, pitch: Decimal, width: Decimal, height: Decimal, x, y_offset: Decimal):
    pads = []
    count = abs(last - first)
    for i in range(count + 1):
        pads.append(Pad(number=first + i if first < last else first - i,
                        x=x,
                        y=y_offset - Decimal(i) * pitch,
                        width=width,
                        height=height
                        ))
    return pads

==> part_library_gen-0.1.19a0-py3-none-any.whl: part_library_gen/generators/footprint_generator/tssop.py <==
from decimal import Decimal
from .footprint import Footprint
from ..components.pad import Pad
from ..components.lines import Lines
from ..components.circle import Circle


class Parameters:
    def __init__(self, pin_count: int, pin_pitch, pad_width, pad_height, pad_row_spacing):
        self.pin_count = pin_count
        self.pin_pitch = pin_pitch
        self.pad_width = pad_width
        self.pad_height = pad_height
        self.pad_row_spacing = pad_row_spacing


def generate(parameters, name):
    row_spacing = parameters.E.typ + 2 * parameters.b.typ - parameters.L.typ
    overlay_d = parameters.D.typ
    overlay_e = parameters.E.typ - parameters.L.typ - Decimal('0.5')
    parameters = Parameters(20,
                            pin_pitch=parameters.e.typ,
                            pad_width=parameters.L.typ,
                            pad_height=parameters.b.typ + Decimal('0.06'),
                            pad_row_spacing=parameters.L.typ + 2*parameters.b.typ-parameters.L.typ)

    pin_count_per_side = int(parameters.pin_count / 2)
    first_pad_y = pin_count_per_side * parameters.pin_pitch / 2
    left_pads = add_vertical_pads(first=1,
                                  last=10,
                                  pitch=parameters.pin_pitch,
                                  width=parameters.pad_width,
                                  height=parameters.pad_height,
                                  x=row_spacing / -2,
                                  y_offset=first_pad_y)
    right_pads = add_vertical_pads(first=20,
                                   last=11,
                                   pitch=parameters.pin_pitch,
                                   width=parameters.pad_width,
                                   height=parameters.pad_height,
                                   x=row_spacing / 2,
                                   y_offset=first_pad_y)

    footprint = Footprint(name)
    footprint.add_pad(left_pads)
    footprint.add_pad(right_pads)

    # add overlay layer
    overlay_rectangle = Lines(overlay_e / -2, overlay_d / 2)
    overlay_rectangle.add_point(overlay_e / -2, overlay_d / -2)
    overlay_rectangle.add_point(overlay_e / 2, overlay_d / -2)
    overlay_rectangle.add_point(overlay_e / 2, overlay_d / 2)
    footprint.add_overlay(overlay_rectangle)
    radius = Decimal('0.5')
    spacing = Decimal('0.5')
    overlay_one_position_mark = Circle(overlay_e / -2 + radius + spacing, overlay_d / 2 - radius - spacing, radius)
    footprint.add_overlay(overlay_one_position_mark)

    footprint.width = row_spacing + 3
    footprint.height = overlay_d + 2
    return footprint


def add_vertical_pads(first, last, pitch: Decimal, width: Decimal, height: Decimal, x, y_offset: Decimal):
    pads = []
    count = abs(last - first)
    for i in range(count + 1):
        pads.append(Pad(number=first + i if first < last else first - i,
                        x=x,
                        y=y_offset - Decimal(i) * pitch,
                        width=width,
                        height=height
                        ))
    return pads
